<?php

namespace Drp\NativeEventApp\Test\Unit;

use Drp\NativeEventApp\Models\Device;
use Drp\NativeEventApp\Test\TestCase;
use Laravel\Passport\Token;

class DeviceTest extends TestCase
{
    /** @test */
    public function it_can_associate_a_token(): void
    {
        $token = factory(Token::class)->state('active')->create();
        $device = factory(Device::class)->create();

        $device = $device->associateAccessToken($token);

        $this->assertEquals($token->id, $device->access_token_id);
        $this->assertEquals($device->token->id, $device->access_token_id);
    }

    /** @test */
    public function it_can_revoke_an_existing_token(): void
    {
        $token = factory(Token::class)->state('active')->create();
        $device = factory(Device::class)->create();

        $device = $device->associateAccessToken($token);

        $device->revokeExistingAccessToken();

        $this->assertEquals(1, $device->token->revoked);
        $this->assertEquals(1, $token->fresh()->revoked);
    }

    /** @test */
    public function it_can_store_the_firebase_device_id_for_the_given_token(): void
    {
        $token = factory(Token::class)->state('active')->create();
        $device = factory(Device::class)->create([
            'access_token_id' => $token->id,
        ]);

        Device::storeFirebaseDeviceId($token, '1234');

        $this->assertEquals('1234', $device->fresh()->firebase_device_id);
    }

    /** @test */
    public function it_can_remove_a_firebase_device_id_for_the_given_token(): void
    {
        $token = factory(Token::class)->state('active')->create();
        $device = factory(Device::class)->create([
            'access_token_id' => $token->id,
            'firebase_device_id' => '1234',
        ]);

        $this->assertNotNull($device->firebase_device_id);

        Device::removeFirebaseDeviceId($token);

        $this->assertNull($device->fresh()->firebase_device_id);
    }

    /** @test */
    public function it_can_get_a_device_from_a_token(): void
    {
        $token = factory(Token::class)->state('active')->create();
        $device = factory(Device::class)->create([
            'access_token_id' => $token->id,
            'firebase_device_id' => '1234',
        ]);

        $result = Device::getByToken($token);

        $this->assertEquals($device->id, $result->id);
        $this->assertEquals($device->access_token_id, $result->access_token_id);
    }
}
