<?php

namespace Drp\NativeEventApp\Test\Unit\Modules;

use Drp\NativeEventApp\Facades\ModulesUnSerializer;
use Drp\NativeEventApp\Modules\Types\VRVideo;
use Drp\NativeEventApp\Test\TestCase;

class VRVideoTest extends TestCase
{
    /** @test */
    public function is_serializable(): void
    {
        $src = 'http://www.example.com/video.mp4';
        $video = VRVideo::make($src, 'test');

        $serializedModule = json_encode([$video]);
        $module = ModulesUnSerializer::getModulesFromString($serializedModule)->first();

        $this->assertInstanceOf(VRVideo::class, $module);
        $this->assertEquals($src, $module->src);
    }

    /** @test */
    public function it_can_set_the_title(): void
    {
        $src = 'http://www.example.com/video.mp4';
        $video = VRVideo::make($src, 'test');
        $video = $video->title('Test Title');

        $serializedModule = json_encode([$video]);
        $module = ModulesUnSerializer::getModulesFromString($serializedModule)->first();

        $this->assertInstanceOf(VRVideo::class, $module);
        $this->assertEquals($src, $module->src);
        $this->assertEquals('Test Title', $module->title);
    }

    /** @test */
    public function it_can_set_the_description(): void
    {
        $src = 'http://www.example.com/video.mp4';
        $video = VRVideo::make($src, 'test');
        $video = $video->description('Test Description');

        $serializedModule = json_encode([$video]);
        $module = ModulesUnSerializer::getModulesFromString($serializedModule)->first();

        $this->assertInstanceOf(VRVideo::class, $module);
        $this->assertEquals($src, $module->src);
        $this->assertEquals('Test Description', $module->description);
    }

    /** @test */
    public function it_can_set_the_preview(): void
    {
        $src = 'http://www.example.com/video.mp4';
        $video = VRVideo::make($src, 'test');
        $video = $video->preview('http://www.example.com/preview.img');

        $serializedModule = json_encode([$video]);
        $module = ModulesUnSerializer::getModulesFromString($serializedModule)->first();

        $this->assertInstanceOf(VRVideo::class, $module);
        $this->assertEquals($src, $module->src);
        $this->assertEquals('http://www.example.com/preview.img', $module->preview);
    }
}
